pub struct TraceForwarder { /* private fields */ }Expand description
Trace forwarder that connects to hermod-tracer
Implementations
Sourceimpl TraceForwarder
impl TraceForwarder
Sourcepub fn new(config: ForwarderConfig) -> Self
pub fn new(config: ForwarderConfig) -> Self
Create a new trace forwarder
Sourcepub fn with_datapoint_store(self, store: DataPointStore) -> Self
pub fn with_datapoint_store(self, store: DataPointStore) -> Self
Attach a DataPointStore so the forwarder can serve named data points
to the acceptor on request.
The same store should be passed to [DatapointBackend::with_store] so
that dispatched trace objects are automatically stored and served.
Sourcepub fn handle(&self) -> ForwarderHandle
pub fn handle(&self) -> ForwarderHandle
Get a handle for sending traces
Sourcepub async fn run(self) -> Result<(), ForwarderError>
pub async fn run(self) -> Result<(), ForwarderError>
Run the forwarder (connects and handles protocol, reconnecting on error)