pub struct TraceForwardClient { /* private fields */ }Expand description
Mux-aware trace-forward client
Implementations
Sourceimpl TraceForwardClient
impl TraceForwardClient
Sourcepub fn new(channel: AgentChannel) -> Self
pub fn new(channel: AgentChannel) -> Self
Create a new client from a multiplexer channel
Sourcepub async fn send_message(&mut self, msg: &Message) -> Result<(), ClientError>
pub async fn send_message(&mut self, msg: &Message) -> Result<(), ClientError>
Send a message to the acceptor
Sourcepub async fn recv_message(&mut self) -> Result<Message, ClientError>
pub async fn recv_message(&mut self) -> Result<Message, ClientError>
Receive a message from the acceptor
Sourcepub async fn handle_request(
&mut self,
traces: Vec<TraceObject>,
) -> Result<(), ClientError>
pub async fn handle_request( &mut self, traces: Vec<TraceObject>, ) -> Result<(), ClientError>
Wait for a trace objects request from the acceptor and send traces
Sourcepub async fn send_done(&mut self) -> Result<(), ClientError>
pub async fn send_done(&mut self) -> Result<(), ClientError>
Send a Done message to close the connection gracefully