pub struct RotationParams {
pub rp_frequency_secs: u32,
pub rp_log_limit_bytes: u64,
pub rp_max_age_hours: u64,
pub rp_keep_files_num: u32,
}Expand description
Log rotation parameters
Fields
rp_frequency_secs: u32How often to check for rotation (seconds)
rp_log_limit_bytes: u64Rotate when the current file exceeds this size (bytes)
rp_max_age_hours: u64Delete files older than this many hours
rp_keep_files_num: u32Always keep at least this many of the newest files